Session

Struct Session 

pub struct Session {
    pub options: Options,
    pub search_paths: SearchPaths,
    /* private fields */
}
The compiler session holds all state for a compilation unit.

This is the primary type for managing compilation state and should be created at the start of compilation and passed through all phases.

Fields

options: Options

Compiler options.

search_paths: SearchPaths

Search paths for modules and libraries.

Implementations

Source

impl Session

pub fn new(options: Options) -> Result<Self, SessionError>

Create a new session with the given options.

Errors

Returns an error if the current working directory cannot be determined.

pub fn with_defaults() -> Result<Self, SessionError>

Create a new session with default options.

Errors

Returns an error if the current working directory cannot be determined.

pub fn working_dir(&self) -> &Utf8Path

Get the working directory for this session.

pub fn profile(&self) -> Profile

Get the compilation profile.

pub fn is_module_loaded(&self, name: &str) -> bool

Check if a module has been loaded (for cycle detection).

pub fn mark_module_loaded(&self, name: String)

Mark a module as loaded.

pub fn output_path(&self, input_name: &str) -> Utf8PathBuf

Get the output path, computing a default if not specified.